specsim
=======

Quick simulations of fiber spectrograph response.

Status reports for developers
-----------------------------

.. image:: https://zenodo.org/badge/41930235.svg
   :target: https://zenodo.org/badge/latestdoi/41930235

.. image:: https://travis-ci.org/desihub/specsim.png?branch=master
    :target: https://travis-ci.org/desihub/specsim
    :alt: Test Status

.. image:: https://readthedocs.org/projects/specsim/badge/?version=latest
    :target: https://readthedocs.org/projects/specsim/?badge=latest
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/desihub/specsim/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/desihub/specsim?branch=master
    :alt: Coverage Status

.. image:: https://img.shields.io/pypi/v/specsim.svg
    :target: https://pypi.python.org/pypi/specsim
    :alt: Distribution Status
